@@ -7,7 +7,7 @@
 # CREATED    : in original form: Apr 1997
 #              completely redone: Oct 1997
 # MODIFIED   : 
-# VERSION    : $Id$
+# VERSION    : $Id: Structure.pm 8423 2010-02-13 20:40:27Z ambs $
 # COPYRIGHT  : Copyright (c) 1997-2000 by Gregory P. Ward.  All rights
 #              reserved.
 # 
@@ -23,9 +23,6 @@ require 5.004;                              # for 'isa' and 'can'
 use strict;
 use Carp;
 
-use vars qw'$VERSION';
-$VERSION = 0.76_02;
-
 use Text::BibTeX ('check_class');
 
 =head1 NAME
@@ -322,8 +319,8 @@ module.  A short example will illustrate this.
 Typically, a C<Text::BibTeX>-based program is based around a kernel of
 code like this:
 
-   $bibfile = Text::BibTeX::File->new("foo.bib");
-   while ($entry = Text::BibTeX::Entry->new($bibfile))
+   $bibfile = new Text::BibTeX::File "foo.bib";
+   while ($entry = new Text::BibTeX::Entry $bibfile)
    {
       # process $entry
    }
@@ -336,9 +333,9 @@ behaviour.  Let us now suppose that C<$bibfile> is expected to conform
 to a database structure specified by C<$structure> (presumably a
 user-supplied value, and thus unknown at compile-time):
 
-   $bibfile = Text::BibTeX::File->new("foo.bib");
+   $bibfile = new Text::BibTeX::File "foo.bib";
    $bibfile->set_structure ($structure);
-   while ($entry = Text::BibTeX::Entry->new($bibfile))
+   while ($entry = new Text::BibTeX::Entry $bibfile)
    {
       # process $entry
    }
@@ -450,7 +447,7 @@ implements the C<Bib> structure.  Use the pseudo-option C<module> to
 override this module name.  For instance, if the structure C<Foo> is
 implemented by the module C<Foo>:
 
-   $structure = Text::BibTeX::Structure->new
+   $structure = new Text::BibTeX::Structure
       ('Foo', module => 'Foo');
 
 This method C<die>s if there are any errors loading/compiling the
@@ -869,9 +866,7 @@ sub get_options
 
 package Text::BibTeX::StructuredEntry;
 use strict;
-use vars qw(@ISA $VERSION);
-$VERSION = 0.76_02;
-
+use vars qw(@ISA);
 use Carp;
 
 @ISA = ('Text::BibTeX::Entry');
